@@ -8,13 +8,18 @@
 #' Pull files from the NEON API, by data product, in a structure that will allow them to be stacked by the stackByTable() function
 #'
 #' @param dpID The identifier of the NEON data product to pull, in the form DPL.PRNUM.REV, e.g. DP1.10023.001
-#' @param site Either the string 'all', or the four-letter code of a single NEON site, e.g. 'CLBJ'. Future versions may allow more options for subsetting than one or all sites. Defaults to all.
+#' @param site Either the string 'all', meaning all available sites, or a character vector of 4-letter NEON site codes, e.g. c('ONAQ','RMNP'). Defaults to all.
+#' @param startdate Either NA, meaning all available dates, or a character vector in the form YYYY-MM, e.g. 2017-01. Defaults to NA.
+#' @param enddate Either NA, meaning all available dates, or a character vector in the form YYYY-MM, e.g. 2017-01. Defaults to NA.
 #' @param package Either 'basic' or 'expanded', indicating which data package to download. Defaults to basic.
 #' @param avg Either the string 'all', or the averaging interval to download, in minutes. Only applicable to sensor (IS) data. Defaults to 'all'.
 #' @param check.size T or F, should the user be told the total file size before downloading? Defaults to T. When working in batch mode, or other non-interactive workflow, use check.size=F.
 #' @param savepath The location to save the output files to
 #' @param load T or F, are files saved locally or loaded directly? Used silently with loadByProduct(), do not set manually.
 
+#' @details All available data meeting the query criteria will be downloaded. Most data products are collected at only a subset of sites, and dates of collection vary. Consult the NEON data portal for sampling details.
+#' Dates are specified only to the month because NEON data are provided in monthly packages. Any month included in the search criteria will be included in the download. Start and end date are inclusive.
+
 #' @return A folder in the working directory (or in savepath, if specified), containing all zip files meeting query criteria.
 
 #' @examples
@@ -33,8 +38,8 @@
 #     original creation
 ##############################################################################################
 
-zipsByProduct <- function(dpID, site="all", package="basic", avg="all", 
-                          check.size=TRUE, savepath=NA, load=F) {
+zipsByProduct <- function(dpID, site="all", startdate=NA, enddate=NA, package="basic", 
+                          avg="all", check.size=TRUE, savepath=NA, load=F) {
 
   messages <- NA
   
@@ -90,16 +95,37 @@ zipsByProduct <- function(dpID, site="all", package="basic", avg="all",
   # get the urls for months with data available
   month.urls <- unlist(avail$data$siteCodes$availableDataUrls)
 
-  # subset to site if requested
-  if(site!="all") {
-    month.urls <- month.urls[grep(site, month.urls)]
+  # subset by sites if requested
+  if(!"all" %in% site) {
+    month.urls <- month.urls[sort(unlist(sapply(site, grep, month.urls)))]
   } else {
     month.urls <- month.urls
   }
-
+  
   # error message if nothing is available
   if(length(month.urls)==0) {
-    stop("There are no data at the selected site.")
+    stop("There are no data at the selected site(s).")
+  }
+  
+  # subset by dates if requested
+  if(!is.na(startdate)) {
+    datelist <- substring(month.urls, nchar(month.urls[1])-6, nchar(month.urls[1]))
+    month.urls <- month.urls[which(datelist >= startdate)]
+  }
+  
+  # error message if nothing is available
+  if(length(month.urls)==0) {
+    stop("There are no data at the selected date(s).")
+  }
+  
+  if(!is.na(enddate)) {
+    datelist <- substring(month.urls, nchar(month.urls[1])-6, nchar(month.urls[1]))
+    month.urls <- month.urls[which(datelist <= enddate)]
+  }
+  
+  # error message if nothing is available
+  if(length(month.urls)==0) {
+    stop("There are no data at the selected date(s).")
   }
   
   # get all the file names, and stash the URLs for just the zips in an object
